@@ -47,6 +47,7 @@
 #include <giunioninfo.h>
 #include <giversionmacros.h>
 #include <givfuncinfo.h>
+#include <giversion.h>
 
 G_BEGIN_DECLS
 
@@ -143,6 +144,10 @@ GITypelib *    g_irepository_require_private (GIRepository  *repository,
 					     GIRepositoryLoadFlags flags,
 					     GError       **error);
 
+GI_AVAILABLE_IN_1_44
+gchar      ** g_irepository_get_immediate_dependencies (GIRepository *repository,
+                                                        const gchar  *namespace_);
+
 GI_AVAILABLE_IN_ALL
 gchar      ** g_irepository_get_dependencies (GIRepository *repository,
 					      const gchar  *namespace_);
