@@ -22,6 +22,7 @@
 
 import os
 import sys
+import operator
 
 from . import utils
 
@@ -36,27 +37,47 @@ class Position(object):
     want to inform about.
     """
 
-    __slots__ = ('filename', 'line', 'column')
+    __slots__ = ('filename', 'line', 'column', 'is_typedef')
 
-    def __init__(self, filename=None, line=None, column=None):
+    def __init__(self, filename=None, line=None, column=None, is_typedef=False):
         self.filename = filename
         self.line = line
         self.column = column
+        self.is_typedef = is_typedef
 
-    def __cmp__(self, other):
-        return cmp((self.filename, self.line, self.column),
-                   (other.filename, other.line, other.column))
+    def _compare(self, other, op):
+        return op((self.filename, self.line, self.column),
+                  (other.filename, other.line, other.column))
+
+    def __lt__(self, other):
+        return self._compare(other, operator.lt)
+
+    def __gt__(self, other):
+        return self._compare(other, operator.gt)
+
+    def __ge__(self, other):
+        return self._compare(other, operator.ge)
+
+    def __le__(self, other):
+        return self._compare(other, operator.le)
+
+    def __eq__(self, other):
+        return self._compare(other, operator.eq)
+
+    def __ne__(self, other):
+        return self._compare(other, operator.ne)
+
+    def __hash__(self):
+        return hash((self.filename, self.line, self.column))
 
     def __repr__(self):
-        return '<Position %s:%d:%d>' % (os.path.basename(self.filename), self.line or -1,
+        return '<Position %s:%d:%d>' % (os.path.basename(self.filename),
+                                        self.line or -1,
                                         self.column or -1)
 
     def format(self, cwd):
-        filename = os.path.realpath(self.filename)
-        cwd = os.path.realpath(cwd)
-        common_prefix = os.path.commonprefix((filename, cwd))
-        if common_prefix:
-            filename = os.path.relpath(filename, common_prefix)
+        filename = os.path.relpath(os.path.realpath(self.filename),
+                                   os.path.realpath(cwd))
 
         if self.column is not None:
             return '%s:%d:%d' % (filename, self.line, self.column)
@@ -69,7 +90,7 @@ class Position(object):
 class MessageLogger(object):
     _instance = None
 
-    def __init__(self, namespace, output=None):
+    def __init__(self, namespace=None, output=None):
         if output is None:
             output = sys.stderr
         self._cwd = os.getcwd()
@@ -130,8 +151,12 @@ class MessageLogger(object):
             text = '%s\n%s\n%s' % (text, marker_line, ' ' * marker_pos + '^')
 
         if prefix:
-            text = ('%s: %s: %s: %s: %s\n' % (last_position, error_type,
-                                              self._namespace.name, prefix, text))
+            if self._namespace:
+                text = ('%s: %s: %s: %s: %s\n' % (last_position, error_type,
+                                                  self._namespace.name, prefix, text))
+            else:
+                text = ('%s: %s: %s: %s\n' % (last_position, error_type,
+                                              prefix, text))
         else:
             if self._namespace:
                 text = ('%s: %s: %s: %s\n' % (last_position, error_type,
@@ -160,9 +185,7 @@ class MessageLogger(object):
         elif context and context.file_positions:
             positions = context.file_positions
         else:
-            positions = []
-            if not context:
-                text = "context=%r %s" % (node, text)
+            positions = set()
 
         if context:
             text = "%s: %s" % (getattr(context, 'symbol', context.name), text)
@@ -174,7 +197,7 @@ class MessageLogger(object):
     def log_symbol(self, log_type, symbol, text):
         """Log a warning in the context of the given symbol."""
         self.log(log_type, text, symbol.position,
-                 prefix="symbol=%r" % (symbol.ident, ))
+                 prefix="symbol='%s'" % (symbol.ident, ))
 
 
 def log_node(log_type, node, text, context=None, positions=None):
@@ -191,6 +214,10 @@ def warn_node(node, text, context=None, positions=None):
     log_node(WARNING, node, text, context=context, positions=positions)
 
 
+def error_node(node, text, context=None, positions=None):
+    log_node(ERROR, node, text, context=context, positions=positions)
+
+
 def warn_symbol(symbol, text):
     ml = MessageLogger.get()
     ml.log_symbol(WARNING, symbol, text)
